@@ -2,6 +2,7 @@
     chips.h - Part of xsensors
 
     Copyright (c) 2002-2007 Kris Kersey <augustus@linuxhardware.org>
+                  2012-2016 Jeremy Newton (mystro256)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,12 +16,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, Boston, MA
+    02110-1301  USA.
 */
 
 #define UNDEFMAXMIN -1
 
-/* Link list to hold sensor feature data.  This is used since the number of 
+/* Link list to hold sensor feature data.  This is used since the number of
  * features vary.
  */
 typedef struct _updates {
