@@ -2,6 +2,7 @@
     main.h - Part of xsensors
 
     Copyright (c) 2002-2007 Kris Kersey <augustus@linuxhardware.org>
+                  2012-2016 Jeremy Newton (mystro256)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,10 +16,10 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, Boston, MA
+    02110-1301  USA.
 */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -27,14 +28,18 @@
 #include <sensors/sensors.h>
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <sys/stat.h>
+#include <gdk/gdk.h>
 #include "chips.h"
 #include "gui.h"
-
-/* Version Number */
-#define VERSION "0.70"
+#include "prefs.h"
+#include "../config.h"
 
 /* Pretty identifiers. */
 enum { SUCCESS, FAILURE };
 
-/* Prototypes */
-int help_msg( void );
+/* Public vars */
+extern int tf;
+extern int update_time;
+extern char *imagefile;
+extern const char *home_dir;
